@@ -71,6 +71,12 @@ has 'links' => (
 		'add_link' => 'push',
 		},
 	);
+
+has 'linked_to' => (
+    is => 'ro',
+    isa => 'Text::TEI::Collate::Word',
+    writer => '_set_linked',
+    );
 	
 has 'variants' => (
 	traits => ['Array'],
@@ -79,9 +85,18 @@ has 'variants' => (
 	handles => {
 		'variants' => 'elements',
 		'add_variant' => 'push',
+		'get_variant' => 'get',
+		'_clear_variants' => 'clear',
 		},
 	);
 
+has 'variant_of' => (
+    is => 'ro',
+    isa => 'Text::TEI::Collate::Word',
+    writer => '_set_variant_of',
+    clearer => '_clear_variant_of',
+    );
+
 has 'ms_sigil' => (
 	is => 'ro',
 	isa => 'Str',
@@ -122,6 +137,10 @@ has '_mutable' => (
 
 $VERSION = "1.0";
 
+=head1 NAME
+
+Text::TEI::Collate::Word - represent a collatable word in a manuscript text
+
 =head1 DESCRIPTION
 
 Text::TEI::Collate::Word is an object that describes a word in a collated
@@ -227,6 +246,22 @@ around BUILDARGS => sub {
 	return $class->$orig( %newargs );
 };
 
+around add_link => sub {
+	my( $orig, $self, @args ) = @_;
+	foreach( @args ) {
+		$_->_set_linked( $self );
+	}
+	$self->$orig( @args );
+};
+
+around add_variant => sub {
+	my( $orig, $self, @args ) = @_;
+	foreach( @args ) {
+		$_->_set_variant_of( $self );
+	}
+	$self->$orig( @args );
+};
+
 sub _init_from_json {
 	my $hash = shift;
 	my %newhash;
@@ -398,6 +433,10 @@ Returns the list of links, or an empty list.
 
 Adds to the list of 'like' words in this word's column.
 
+=head2 linked_to
+
+Returns the (base) word, if any, that this word is linked to.
+
 =head2 variants
 
 Returns the list of variants, or an empty list.
@@ -406,6 +445,24 @@ Returns the list of variants, or an empty list.
 
 Adds to the list of 'different' words in this word's column.
 
+=head2 variant_of
+
+Returns the word of which this word is a variant.
+
+=head2 unlink_variant
+
+Removes the given word from this word's list of variants.
+
+=cut
+
+sub unlink_variant {
+    my( $self, $other ) = @_;
+    my @v = grep { $_ ne $other } $self->variants;
+    $self->_clear_variants();
+    $self->add_variant( @v );
+    $other->_clear_variant_of;
+}
+
 =head2 state
 
 Returns a hash of all the values that might be changed by a re-comparison.
